@@ -57,12 +57,12 @@ class Midi(object):
         9.5: ('B', -1.5, 0),
         10: ('B', -1, 0),
         10.5: ('B', -0.5, 0),
-        11: ('C', -1, 1),
+        11: ('B', 0, 0),
         11.5: ('C', -0.5, 1)
     }
 
     sharp = {
-        0: ('B', 1, -1),
+        0: ('C', 0, 0),
         0.5: ('C', 0.5, 0),
         1: ('C', 1, 0),
         1.5: ('C', 1.5, 0),
@@ -229,12 +229,6 @@ class Midi(object):
 
     def __le__(self, other):  # For x <= y
         return self.value <= other.value
-    #
-    # def __eq__(self, other):  # For x == y
-    #     return self.value == other.value
-    #
-    # def __ne__(self, other):  # For x != y OR x <> y
-    #     return self.value != other.value
 
     def __gt__(self, other):  # For x > y
         return self.value > other.value
