@@ -1,11 +1,11 @@
 import math
 import warnings
 
-from musicscore.musictree.treechordflags import TreeChordFlag
 from quicktions import Fraction
 
 from musicscore.basic_functions import flatten
 from musicscore.musictree.treechord import TreeChord
+from musicscore.musictree.treechordflags import TreeChordFlag, FingerTremoloFlag
 from musicscore.musicxml.elements.note import TimeModification
 from musicscore.musicxml.types.complextypes.timemodification import ActualNotes, NormalNotes, NormalType
 
@@ -256,9 +256,6 @@ class TreeBeat(object):
             elif chord.quarter_duration == Fraction(11, 1):
                 if chord.position_in_beat == 0:
                     split = chord.split(4, 7)
-            # elif chord.quarter_duration == Fraction(12, 1):
-            #     if chord.position_in_beat == 0:
-            #         split = chord.split(8, )
             elif chord.quarter_duration == Fraction(13, 1):
                 if chord.position_in_beat == 0:
                     split = chord.split(8, 5)
@@ -289,34 +286,33 @@ class TreeBeat(object):
             elif chord.quarter_duration == Fraction(22, 1):
                 if chord.position_in_beat == 0:
                     split = chord.split(8, 14)
-
             elif chord.quarter_duration == Fraction(23, 1):
                 if chord.position_in_beat == 0:
                     split = chord.split(8, 15)
-
             elif chord.quarter_duration == Fraction(24, 1):
                 if chord.position_in_beat == 0:
                     split = chord.split(8, 16)
-
             elif chord.quarter_duration == Fraction(25, 1):
                 if chord.position_in_beat == 0:
                     split = chord.split(8, 17)
-
-            if chord.quarter_duration == Fraction(9, 2):
-                if chord.position_in_beat == 0:
-                    split = chord.split(8, 1)
-
-            if chord.quarter_duration == Fraction(5, 2):
+            elif chord.quarter_duration == Fraction(3, 2):
+                if chord.position_in_beat == 0.5:
+                    split = chord.split(1, 2)
+            elif chord.quarter_duration == Fraction(5, 2):
                 if chord.position_in_beat == 0:
                     split = chord.split(2, 3)
                 elif chord.position_in_beat == 0.5:
-                    split = chord.split(3, 2)
-
-            if chord.quarter_duration == Fraction(7, 2):
+                    split = chord.split(1, 4)
+            elif chord.quarter_duration == Fraction(7, 2):
                 if chord.position_in_beat == 0:
                     split = chord.split(4, 3)
+                elif chord.position_in_beat == 0.5:
+                    split = chord.split(1, 6)
+            elif chord.quarter_duration == Fraction(9, 2):
+                if chord.position_in_beat == 0:
+                    split = chord.split(8, 1)
 
-            if chord.quarter_duration == Fraction(1, 4):
+            elif chord.quarter_duration == Fraction(1, 4):
                 if chord.position_in_beat == Fraction(3, 8):
                     split = chord.split(1, 1)
             elif chord.quarter_duration == Fraction(3, 8):
@@ -567,7 +563,8 @@ class TreeBeat(object):
                     if len(new_chords) == 1:
                         output.extend(new_chords)
                     else:
-                        if diff > 0:
+                        if diff > 0 and (isinstance(chord_flag, FingerTremoloFlag) or
+                                         chord.position_in_beat + new_chords[0].quarter_duration >= self.duration):
                             next_beat = self.next
 
                             if not next_beat.chords:
@@ -578,6 +575,7 @@ class TreeBeat(object):
                             output.extend(new_chords[:-1])
                         else:
                             output.extend(new_chords)
+
                 except IndexError:
                     output.append(chord)
 
