@@ -13,7 +13,7 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
 
     def test_1(self):
-        sf = SimpleFormat(durations=[1, 3.5])
+        sf = SimpleFormat(quarter_durations=[1, 3.5])
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score, 2, 2)
         result_path = path + '_test_1'
